.. int2code-xaudio documentation master file, created by
   sphinx-quickstart on Wed Apr  9 13:03:19 2025.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

int2code-xaudio documentation
=============================

.. if needed use .. include:: alias.txt directive
.. include:: ../README.md
    :parser: myst_parser.sphinx_

.. toctree::
    :maxdepth: 3

    Installation <installation.rst>
    Tutorials <tutorials/index.rst>
    API <modules/modules.rst>
    Contributing <contribute.rst>
    Release Notes <release_notes.rst>

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`